@@ -1,12 +1,9 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE DataKinds #-}
-{-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE LambdaCase #-}
-{-# LANGUAGE NamedFieldPuns #-}
 {-# LANGUAGE QuasiQuotes #-}
 {-# LANGUAGE RecordWildCards #-}
 {-# LANGUAGE TemplateHaskell #-}
-{-# LANGUAGE TypeApplications #-}
 
 module Main (main) where
 
@@ -14,12 +11,12 @@ import Control.Exception (throwIO)
 import Control.Monad
 import Data.Bool (bool)
 import Data.List (intercalate, isSuffixOf, sort)
-import qualified Data.Map.Strict as Map
+import Data.Map.Strict qualified as Map
 import Data.Maybe (fromMaybe, mapMaybe, maybeToList)
-import qualified Data.Set as Set
-import qualified Data.Text.IO as TIO
+import Data.Set qualified as Set
+import Data.Text.IO qualified as TIO
 import Data.Version (showVersion)
-import qualified Data.Yaml as Yaml
+import Data.Yaml qualified as Yaml
 import Language.Haskell.TH.Env (envQ)
 import Options.Applicative
 import Ormolu
@@ -34,7 +31,7 @@ import Ormolu.Utils.IO
 import Paths_fourmolu (version)
 import System.Directory
 import System.Exit (ExitCode (..), exitWith)
-import qualified System.FilePath as FP
+import System.FilePath qualified as FP
 import System.IO (hPutStrLn, stderr)
 
 -- | Entry point of the program.
@@ -282,7 +279,7 @@ data CabalOpts = CabalOpts
 
 optsParserInfo :: ParserInfo Opts
 optsParserInfo =
-  info (helper <*> ver <*> exts <*> optsParser) . mconcat $
+  info (helper <*> ver <*> exts <*> printDefaults <*> optsParser) . mconcat $
     [fullDesc]
   where
     ver :: Parser (a -> a)
@@ -308,6 +305,13 @@ optsParserInfo =
         ]
     displayExts = unlines $ sort (showOutputable <$> manualExts)
 
+    printDefaults :: Parser (a -> a)
+    printDefaults =
+      infoOption defaultPrinterOptsYaml . mconcat $
+        [ long "print-defaults",
+          help "Print default configuration options that can be used in fourmolu.yaml"
+        ]
+
 optsParser :: Parser Opts
 optsParser =
   Opts
